# Electromagnetics constraints

## Boundary conditions

::: phydrax.constraints.ContinuousPECBoundaryConstraint

---

::: phydrax.constraints.ContinuousPMCBoundaryConstraint

---

::: phydrax.constraints.ContinuousImpedanceBoundaryConstraint

---

::: phydrax.constraints.ContinuousElectricSurfaceChargeBoundaryConstraint

---

::: phydrax.constraints.ContinuousMagneticSurfaceCurrentBoundaryConstraint

---

::: phydrax.constraints.ContinuousInterfaceNormalBContinuityConstraint

---

::: phydrax.constraints.ContinuousInterfaceNormalDJumpConstraint

---

::: phydrax.constraints.ContinuousInterfaceTangentialEContinuityConstraint

---

::: phydrax.constraints.ContinuousInterfaceTangentialHJumpConstraint

---

::: phydrax.constraints.DiscretePECBoundaryConstraint

---

::: phydrax.constraints.DiscretePMCBoundaryConstraint

---

::: phydrax.constraints.DiscreteElectricSurfaceChargeBoundaryConstraint

---

::: phydrax.constraints.DiscreteMagneticSurfaceCurrentBoundaryConstraint

---

::: phydrax.constraints.DiscreteInterfaceNormalBContinuityConstraint

---

::: phydrax.constraints.DiscreteInterfaceNormalDJumpConstraint

---

::: phydrax.constraints.DiscreteInterfaceTangentialEContinuityConstraint

---

::: phydrax.constraints.DiscreteInterfaceTangentialHJumpConstraint

## Integral / global constraints

::: phydrax.constraints.EMBoundaryChargeConstraint

---

::: phydrax.constraints.EMPoyntingFluxBoundaryConstraint

---

::: phydrax.constraints.MagneticFluxZeroConstraint
